/// <reference types="lodash" />
import { StoreModule } from '../StoreModule/StoreModule';
export declare type IId = string | number;
export interface IWithId {
    id: IId;
}
export interface ICRUDApi {
    add: string;
    list: string;
    get: string;
    edit: string;
    delete: string;
}
export declare abstract class AbstractCRUDRepository<T extends IWithId> extends StoreModule {
    api: ICRUDApi;
    get hasList(): boolean;
    get isListEmpty(): boolean;
    get isLocalListEmpty(): boolean;
    get localList(): T[];
    get addedIndex(): (instance: T) => number;
    get deletedIndex(): (instance: T) => number;
    get deletedIndexById(): (id: IId) => number;
    get editedIndex(): (instance: T) => number;
    get editedIndexById(): (id: IId) => number;
    get listFirstItem(): T;
    get listLastItem(): T;
    get listLastIndex(): number;
    get listLength(): number;
    get listItemByIndex(): (index: number) => T;
    get listItemById(): (id: IId) => T;
    get listIndex(): (instance: T) => number;
    get listIndexById(): (id: IId) => number;
    get first(): T;
    get last(): T;
    get localListFirstItem(): T;
    get localListLastItem(): T;
    get localListLastIndex(): number;
    get localListLength(): number;
    get localListItemByIndex(): (index: number) => T;
    get localListItemById(): (id: IId) => T;
    get localListIndex(): (instance: T) => number;
    get localListIndexById(): (id: IId) => number;
    get deletedMap(): import("lodash").Dictionary<T>;
    get addedMap(): import("lodash").Dictionary<T>;
    get editedMap(): import("lodash").Dictionary<T>;
    get listMap(): import("lodash").Dictionary<T>;
    get localListMap(): import("lodash").Dictionary<T>;
    get hasAdded(): boolean;
    get isAdded(): (instance: T) => boolean;
    get addedById(): (id: IId) => T;
    get isAddedById(): (id: IId) => boolean;
    get hasEdited(): boolean;
    get isEdited(): (instance: T) => boolean;
    get editedById(): (id: IId) => T;
    get isEditedById(): (id: IId) => boolean;
    get hasDeleted(): boolean;
    get isDeleted(): (instance: T) => boolean;
    get deletedById(): (id: IId) => T;
    get isDeletedById(): (id: IId) => boolean;
    get hasActive(): boolean;
    get isActive(): (instance: T) => boolean;
    get isActiveNew(): boolean;
    get isActiveById(): (id: string | number) => boolean;
    get listIds(): Array<IId>;
    get localListIds(): Array<IId>;
    get isActiveChangedAfterActivation(): boolean;
    added: T[];
    edited: T[];
    deleted: T[];
    list: T[] | undefined;
    active: T;
    activeInitialCopy: T | undefined;
    constructor(api: ICRUDApi);
    activate(instance: T): this;
    deactivate(): this;
    activateFirst(): this;
    activateLast(): this;
    activateByIndex(index: number): this;
    activateInstead(insteadInstance: T, instanceToActivate: T): this;
    activateInsteadById(id: string | number, instanceToActivate: T): this;
    deactivateIfActive(instance: T): this;
    resetActiveToInitialState(): this;
    setList(list: T[]): this;
    addLocal(instance: T): this;
    deleteAdded(instance: T): this;
    deleteAllAdded(): this;
    editLocal(instance: T): this;
    deleteEdited(instance: T): this;
    deleteAllEdited(): this;
    deleteLocal(instance: T): this;
    deleteActiveLocal(): this;
    deleteDeleted(instance: T): this;
    deleteAllDeleted(): this;
    clear(): this;
    clearList(): this;
    sendUpsertReq(instance: T, ...params: any[]): Promise<any>;
    abstract sendAddReq(instance: T, ...params: any[]): Promise<T>;
    abstract sendEditReq(instance: T, ...params: any[]): Promise<T>;
    abstract sendDeleteReq(instance: T, ...params: any[]): Promise<void>;
    abstract sendListReq(...params: any[]): Promise<T[]>;
    abstract sendGetReq(id: IId, ...params: any[]): Promise<T>;
    flushAdded(instance: T, ...params: any[]): Promise<T>;
    flushAllAdded(...params: any[]): Promise<Array<T>>;
    flushEdited(instance: T, ...params: any[]): Promise<T>;
    flushAllEdited(...params: any[]): Promise<Array<T>>;
    flushDeleted(instance: T, ...params: any[]): Promise<void>;
    flushAllDeleted(...params: any[]): Promise<Array<void>>;
    flush(): Promise<void>;
    add(instance: T, ...params: any[]): Promise<T>;
    addAndActivate(instance: T, ...params: any[]): Promise<T>;
    edit(instance: T, ...params: any[]): Promise<T>;
    upsert(instance: T, ...params: any[]): Promise<T>;
    upsertAndActivate(instance: T): Promise<T>;
    upsertActive(): Promise<T | undefined>;
    delete(instance: T, ...params: any[]): Promise<void>;
    deleteActive(...params: any[]): Promise<void>;
    deleteByIndex(index: number, ...params: any[]): Promise<void>;
    smartUpsert(instance: T, ...params: any[]): Promise<T>;
    smartUpsertActive(...params: any[]): Promise<T>;
    smartDelete(instance: T, ...params: any[]): Promise<void>;
    smartDeleteActive(): Promise<void>;
    smartUpsertAndActivate(instance: T): Promise<T>;
    updateList(...params: any[]): Promise<T[]>;
    getAndActivate(id: IId, ...params: any[]): Promise<T>;
    refreshItem(instance: T, ...params: any[]): Promise<T>;
    refreshItemById(id: IId): Promise<T>;
    protected getLocalList(): T[];
    protected addToList(instance: T): this;
    protected editInList(instance: T): this;
    protected deleteFromList(instance: T): this;
    protected deleteActiveFromList(): this;
    protected smartReplace(replaceableInstance: T, replacingInstance: T): this;
    protected replaceAdded(replaceableInstance: T, replacingInstance: T): this;
    protected replaceEdited(replaceableInstance: T, replacingInstance: T): this;
    protected replaceDeleted(replaceableInstance: T, replacingInstance: T): this;
    protected replaceInList(replaceableInstance: T, replacingInstance: T): this;
    protected setActiveInitialCopy(instance: T): this;
    protected clearActiveInitialCopy(): this;
    protected throwErrorIfHasntList(): void;
    protected throwErrorIfHasntActive(): void;
}
